==> gthumb-2.9.2.tar.gz: gthumb-2.9.2/libgthumb/jpegutils/jpegtran.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2001, 2002 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#include <config.h>

#ifndef JPEGTRAN_H
#define JPEGTRAN_H

#include <glib.h>
#include "transupp.h"

typedef boolean (*jpegtran_mcu_callback) (const char  *path,
					  JXFORM_CODE *transform,
					  boolean     *trim,
					  void        *userdata);

#define JPEGTRAN_MCU_CONTINUE	((jpegtran_mcu_callback)0)
#define JPEGTRAN_MCU_TRIM	((jpegtran_mcu_callback)-1)
#define JPEGTRAN_MCU_CANCEL	((jpegtran_mcu_callback)-2)

int jpegtran (const char *input_filename,
		const char *output_filename,
		JXFORM_CODE transformation,
		jpegtran_mcu_callback callback,
		void *userdata,
		GError **error);

#endif /* JPEGTRAN_H */

==> gthumb-2.10.3.tar.gz: gthumb-2.10.3/libgthumb/jpegutils/jpegtran.h <==
/* -*- Mode: C; tab-width: 8; indent-tabs-mode: t; c-basic-offset: 8 -*- */

/*
 *  GThumb
 *
 *  Copyright (C) 2001, 2002 The Free Software Foundation, Inc.
 *
 *  This program is free software; you can redistribute it and/or modify
 *  it under the terms of the GNU General Public License as published by
 *  the Free Software Foundation; either version 2 of the License, or
 *  (at your option) any later version.
 *
 *  This program is distributed in the hope that it will be useful,
 *  but WITHOUT ANY WARRANTY; without even the implied warranty of
 *  MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 *  GNU General Public License for more details.
 *
 *  You should have received a copy of the GNU General Public License
 *  along with this program; if not, write to the Free Software
 *  Foundation, Inc., 59 Temple Street #330, Boston, MA 02111-1307, USA.
 */

#include <config.h>

#ifndef JPEGTRAN_H
#define JPEGTRAN_H

#include <glib.h>
#include <libexif/exif-data.h>
#include "transupp.h"

typedef boolean (*jpegtran_mcu_callback) (JXFORM_CODE *transform,
					  boolean     *trim,
					  void        *userdata);

#define JPEGTRAN_MCU_CONTINUE	((jpegtran_mcu_callback)0)
#define JPEGTRAN_MCU_TRIM	((jpegtran_mcu_callback)-1)
#define JPEGTRAN_MCU_CANCEL	((jpegtran_mcu_callback)-2)

int jpegtran (const char *input_filename,
		const char *output_filename,
		JXFORM_CODE transformation,
		jpegtran_mcu_callback callback,
		void *userdata,
		GError **error);

void update_exif_orientation (ExifData *edata);

#endif /* JPEGTRAN_H */
